.. _web_module:

:mod:`cubicweb_web`
===================

.. automodule:: cubicweb_web

    Exceptions
    ----------

    .. autoexception:: DirectResponse
    .. autoexception:: InvalidSession
    .. autoexception:: PublishException
    .. autoexception:: LogOut
    .. autoexception:: Redirect
    .. autoexception:: StatusResponse
    .. autoexception:: RequestError
    .. autoexception:: NothingToEdit
    .. autoexception:: ProcessFormError
    .. autoexception:: NotFound
    .. autoexception:: RemoteCallFailed
